@@ -1,10 +1,9 @@
 
 package Coro::ProcessPool::Pipeline;
-$Coro::ProcessPool::Pipeline::VERSION = '0.26_005'; # TRIAL
+# ABSTRACT: A producer/consumer pipeline for Coro::ProcessPool
+$Coro::ProcessPool::Pipeline::VERSION = '0.26_006'; # TRIAL
 
-$Coro::ProcessPool::Pipeline::VERSION = '0.26005';# ABSTRACT: A producer/consumer pipeline for Coro::ProcessPool
-
-use Moo;
+$Coro::ProcessPool::Pipeline::VERSION = '0.26006';use Moo;
 use Types::Standard qw(-types);
 use Carp;
 use Coro;
@@ -84,19 +83,11 @@ sub queue {
   croak 'pipeline is shut down' if $self->is_shutdown;
   croak 'pipeline is shutting down' if $self->shutting_down;
 
-  unless ($self->pool->is_running) {
-    unless ($self->is_shutdown || $self->shutting_down) {
-      $self->shutdown;
-    }
-
-    croak 'pool is not running';
-  }
-
   my $deferred = $self->pool->defer(@args);
 
   async_pool {
     my ($self, $deferred) = @_;
-    my $result = eval { $deferred->() };
+    my $result = eval { $deferred->recv };
 
     $self->complete->put([$result, $@]);
     --$self->{num_pending};
@@ -133,7 +124,7 @@ Coro::ProcessPool::Pipeline - A producer/consumer pipeline for Coro::ProcessPool
 
 =head1 VERSION
 
-version 0.26_005
+version 0.26_006
 
 =head1 SYNOPSIS
 
@@ -185,8 +176,8 @@ available.
 
 =head2 queue($task, $args)
 
-Queues a new task. Arguments are identical to L<Coro::ProcessPool::process> and
-L<Coro::ProcessPool::defer>.
+Queues a new task. Arguments are identical to L<Coro::ProcessPool/process> and
+L<Coro::ProcessPool/defer>.
 
 =head2 shutdown
 
