@@ -1,8 +1,8 @@
 package Coro::ProcessPool::Util;
 # ABSTRACT: Utility functions and constants used by Coro::ProcessPool
-$Coro::ProcessPool::Util::VERSION = '0.26_005'; # TRIAL
+$Coro::ProcessPool::Util::VERSION = '0.26_006'; # TRIAL
 
-$Coro::ProcessPool::Util::VERSION = '0.26005';use strict;
+$Coro::ProcessPool::Util::VERSION = '0.26006';use strict;
 use warnings;
 use Carp;
 use Config;
@@ -22,9 +22,11 @@ our @EXPORT_OK = qw(
   encode
   decode
   $EOL
+  $CPUS
 );
 
-const our $EOL => "\n";
+const our $EOL  => "\n";
+const our $CPUS => cpu_count();
 
 my $ENCODER = Sereal::Encoder->new();
 my $DECODER = Sereal::Decoder->new();
@@ -53,7 +55,7 @@ sub encode {
 sub decode {
   my $line = shift or croak 'decode: expected line';
   my $pickled = decode_base64($line);
-  my $package = sereal_decode_with_object($DECODER, $pickled);
+  sereal_decode_with_object($DECODER, $pickled, my $package);
 
   my ($id, $info, $data) = @{$package}{qw(id info data)};
 
@@ -165,7 +167,7 @@ Coro::ProcessPool::Util - Utility functions and constants used by Coro::ProcessP
 
 =head1 VERSION
 
-version 0.26_005
+version 0.26_006
 
 =head1 AUTHOR
 
